@@ -1,3 +1,21 @@
+/* 
+ * Copyright (C) 1999 Robert Wilhelm
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ */
+
 #include <config.h>
 #include <gnome.h>
 
@@ -6,13 +24,11 @@
 #include <string.h>
 
 #include "portab.h"
-#include "makros.h"
-#include "typedef.h"
-#include "var.h"
+#include "position.h"
 #include "pro.h"
-#include "partie.h"
+#include "movlist.h"
 #include "disk.h"
-#include "txt_load.h"
+#include "pgn.h"
 
 static void open_st(const char *fname)
 {
@@ -22,24 +38,23 @@ static void open_st(const char *fname)
 static void write_txt(const char *file)
 {
   FILE *fp;
-  BYTE newbuf[1024]; 
+  char newbuf[2048]; 
 
-  notation_erzeugen(newbuf);
+  generate_notation(newbuf,sizeof(newbuf));
   
   fp = fopen(file,"w");
   if(fp == NULL) 
     {
-      abort();
+      /*      abort();  */
       return;
     }
 
   if(fputs(newbuf,fp)==EOF)
     {
-      abort();
+      /* abort(); */
     }
 
-  if(fclose(fp))
-      abort();
+  fclose(fp);
 }
 
 static void
