@@ -1,6 +1,6 @@
 #include <config.h>
 #include <gnome.h>
-#include "child.h"
+#include "engine.h"
 #include "menu.h"
 
 static GtkWidget *move_entry;
