@@ -1,3 +1,21 @@
+/* 
+ * Copyright (C) 1999 Robert Wilhelm
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ */
+
 #include <gnome.h>
 
 #include <glib.h>
@@ -11,14 +29,12 @@
 
 #include "portab.h"
 #include "makros.h"
-#include "typedef.h"
-#include "var.h"
+#include "position.h"
 #include "pro.h"
-#include "partie.h"
-#include "txt_load.h"
+#include "movlist.h"
 #include "cho1.h"
-#include "ini.h"
 #include "board.h"
+#include "pgn.h"
 
 #define DEBUG 
 
@@ -210,6 +226,7 @@ void pgn_open(const char *fname)
   GtkWidget *clist;
   int i,n;
   int file;
+  gchar *text;
   GList *game_list;
   GScanner *s = pgn_scanner_init();
 
@@ -231,6 +248,16 @@ void pgn_open(const char *fname)
       pgn_clist_add(clist,tag);
     }
 
+	/* If there are any games set up the names and results properly */
+	if (n>0) {
+		gtk_clist_get_text(GTK_CLIST(clist), 0, 0, &text );
+		gtk_label_set_text(GTK_LABEL(board.whitename), text);
+		gtk_clist_get_text(GTK_CLIST(clist), 0, 1, &text );
+		gtk_label_set_text(GTK_LABEL(board.blackname), text);
+		gtk_clist_get_text(GTK_CLIST(clist), 0, 2, &text );
+		gnomechess_movelist_set_result(board.movelist, text);
+	}
+
   close(file);
   g_scanner_destroy(s);
 }
@@ -371,7 +398,8 @@ static int txt_load(char *newbuf, int len, int test)
   int ret =FALSE;
   GScanner *s = pgn_scanner_init();
 
-  ini_game();
+  gnomechess_position_set_initial(currPositionPtr);
+  gnomechess_movelist_clear(board.movelist);
 
   g_scanner_input_text(s,newbuf,len);
 
@@ -585,9 +613,9 @@ static void delete_equal(char *str)
 
 static inline int txt_reg_move_found(BYTE *aq, int test)
 {
-	    int piece=feld[*aq];
-	    make_move(*aq,*(aq+1));
-	    if (!test) notation_update(piece,*aq,*(aq+1));
+	    int piece=currPositionPtr->square[*aq];
+	    gnomechess_position_make_move(currPositionPtr,*aq,*(aq+1));
+	    if (!test) gnomechess_movelist_add(board.movelist, piece,*aq,*(aq+1));
 	    return TRUE;		
 }
 
@@ -611,7 +639,7 @@ static int txt_reg_move(char *str, int test)
   for ( aq = ap , i = 0 ; i < anz ; i++ , aq += 2 ) 
   {
     p=liste[i];
-    piece_move_to_ascii(p,feld[(WORD)*aq],*aq,*(aq+1));
+    piece_move_to_ascii(p,currPositionPtr->square[(WORD)*aq],*aq,*(aq+1));
     if ( *p == ' ')  /* pawn move */
       {
 	p++;         /* e.g. e2e4 */
@@ -726,15 +754,25 @@ clist_click_column (GtkCList * clist, gint column, gpointer data)
 static void
 select_game(GtkWidget * widget,int row,int column,GdkEventButton * event,GList *game_list)
 {
-  FILE *fp;
-  printf("select game");
+	FILE *fp;
+	gchar *text;
+	printf("select game");
 
-  fp = fopen(filename,"r");
-  if (fp)
-    {
-      fseek(fp,(long) g_list_nth_data(game_list,row),SEEK_SET);
-      txt_load_from_fp(fp, (long)g_list_nth_data(game_list,row+1) - (long)g_list_nth_data(game_list,row), FALSE);
-      update_board();
+	fp = fopen(filename,"r");
+	if (fp) {
+		fseek(fp,(long) g_list_nth_data(game_list,row),SEEK_SET);
+		txt_load_from_fp(fp, (long)g_list_nth_data(game_list,row+1) -
+								(long)g_list_nth_data(game_list,row), FALSE);
+
+		/* Now set up the names and results properly */
+		gtk_clist_get_text(GTK_CLIST(widget), row, 0, &text );
+		gtk_label_set_text(GTK_LABEL(board.whitename), text);
+		gtk_clist_get_text(GTK_CLIST(widget), row, 1, &text );
+		gtk_label_set_text(GTK_LABEL(board.blackname), text);
+		gtk_clist_get_text(GTK_CLIST(widget), row, 2, &text );
+		gnomechess_movelist_set_result(board.movelist, text);
+
+		update_board();
     }
 }
 
