@@ -11,7 +11,5 @@ void notation_update(int piece, int from, int to);
 WORD reg_zug(WORD von,WORD nach);
 void rueck_w(WORD,WORD);
 void rueck_s(WORD,WORD);
-void string_alert(const char *);
-void make_move(int from, int to);
 int  move_generator(BYTE **,WORD *,WORD *);
 #endif /* _PRO_H */
